<?php header('Content-type: text/html; charset=utf-8'); ?>
<?php

/******************************************************************
// load viewer library
*******************************************************************/
$libraryPath = 'cmsAdmin/lib/viewer_functions.php';
$dirsToCheck = ['','../','../../','../../../','../../../../']; // add if needed: '/home/...'
foreach ($dirsToCheck as $dir) { if (@include_once("$dir$libraryPath")) { break; }}
if (!function_exists('getRecords')) { die("Couldn't load viewer library, check filepath in sourcecode."); }

include_once 'calendar_functions.php';

// Retrieve and validate GET parameters for the view and navigation
$params = getCalendarParams();
$view  = $params['view'];
$year  = $params['year'];
$month = $params['month'];
$week  = $params['week'];
$day   = $params['day'];


// Determine if we're in example mode or production mode (can be based on a constant or environment variable)
$mode = 'example'; // or 'production'


// Check the execution mode
if ($mode === 'production') {

	$FORMAT_START = 'Y-m-d 00:00:00';  // Format for the start of a period (midnight)
	$FORMAT_END   = 'Y-m-d 23:59:59';  // Format for the end of a period (11:59 PM)

	switch ($view) {
		case 'month':
			// Create a date for the first day of the month
			$date = sprintf("%04d-%02d-01", $year, $month);
			
			// For the month, take the previous and next month
			$debut = date($FORMAT_START, strtotime("$date -1 month"));               // Previous month
			$fin   = date($FORMAT_END, strtotime("$date +1 month +1 month -1 day")); // End of the next month
			
			// Look for events that overlap with this period
			$query = "start_date <= '$fin' AND end_date >= '$debut'";
			break;

		case 'week':
			// Create a date for the first day of the week
			$debut_semaine = date($FORMAT_START, strtotime("{$year}-W{$week}"));
			
			// Take the previous and next week
			$debut = date($FORMAT_START, strtotime("$debut_semaine -1 week"));      // Previous week
			$fin   = date($FORMAT_END, strtotime("$debut_semaine +2 week -1 day")); // End of the next week
			
			// Look for events that overlap with this period
			$query = "start_date <= '$fin' AND end_date >= '$debut'";
			break;

		case 'day':
			// Create the start and end dates for the specified day
			$debut = sprintf("%04d-%02d-%02d 00:00:00", $year, $month, $day);
			$fin   = sprintf("%04d-%02d-%02d 23:59:59", $year, $month, $day);
			
			// Look for events happening on that day
			$query = "(start_date BETWEEN '$debut' AND '$fin') 
					  OR (end_date BETWEEN '$debut' AND '$fin')
					  OR (start_date <= '$debut' AND end_date >= '$fin')";
			break;
			
		case 'year':
			// Create the start and end dates for the year
			$debut = sprintf("%04d-01-01 00:00:00", $year);
			$fin   = sprintf("%04d-12-31 23:59:59", $year);
			
			// Look for events happening this year
			$query = "(start_date BETWEEN '$debut' AND '$fin') 
					  OR (end_date BETWEEN '$debut' AND '$fin')
					  OR (start_date <= '$debut' AND end_date >= '$fin')";
			break;
			
		default:
			// If the view is not valid, return an empty string
			$query = "";
			break;
	}

    // Load records from the 'events' table
    list($events) = getRecords(array(
        'tableName'   => 'events',
        'where'       => $query,
        'loadUploads' => true,
        'allowSearch' => false,
        'debugSql'    => false,
    ));

} else {

	// Example mode: use a static array with mock events
	$events = [
		[
			'title' => 'Annual Conference',
			'start_date' => '2024-11-12 09:00:00',
			'end_date' => '2024-11-12 09:10:00',
			'permalink' => 'annual-conference',
			'description' => 'Annual conference on technological innovations.',
			'location' => 'Main Auditorium',
			'category' => 'conference'
		],
		[
			'title' => 'Digital Marketing Seminar',
			'start_date' => '2024-10-22 10:00:00',
			'end_date' => '2024-10-22 15:00:00',
			'permalink' => 'digital-marketing-seminar',
			'description' => 'Seminar on the latest trends in digital marketing.',
			'location' => 'Meeting Room B',
			'category' => 'conference'
		],
		[
			'title' => 'Team Meeting',
			'start_date' => '2024-10-25 14:00:00',
			'end_date' => '2024-10-26 12:00:00',
			'permalink' => 'team-meeting',
			'description' => 'Weekly team meeting to discuss progress.',
			'location' => 'Conference Room C',
			'category' => 'conference'
		],
		[
			'title' => 'PHP Workshop...',
			'start_date' => '2024-11-02 07:30:00',
			'end_date' => '2024-11-02 17:00:00',
			'permalink' => 'php-workshop',
			'description' => 'A hands-on workshop on PHP development.',
			'location' => 'Training Room D',
			'category' => 'workshop'
		],
		[
			'title' => 'Product Launch',
			'start_date' => '2024-11-30 10:00:00',
			'end_date' => '2024-11-30 16:00:00',
			'permalink' => 'product-launch',
			'description' => 'Launch event for our new product.',
			'location' => 'Main Hall',
			'category' => 'workshop'
		],
		[
			'title' => 'Holiday Party W49',
			'start_date' => '2024-12-01 18:00:00',
			'end_date' => '2024-12-06 12:00:00',
			'permalink' => 'holiday-party',
			'description' => 'Annual holiday party for all employees.',
			'location' => 'Rooftop Lounge',
			'holiday' => 'holiday'
		],
		[
			'title' => 'Year-End Review W49',
			'start_date' => '2024-12-02 14:00:00',
			'end_date' => '2024-12-02 17:00:00',
			'permalink' => 'year-end-review',
			'description' => 'Review of the year\'s achievements and goals.',
			'location' => 'Conference Room A',
			'category' => 'conference'
		]
	];
}

/******************************************************************
// Set HTTP headers for cache control
*******************************************************************/
header('Cache-Control: no-cache, no-store, must-revalidate'); // No caching allowed
header('Expires: 0'); // Set expiration to 0
header_remove('Pragma'); // Remove pragma header

?><!DOCTYPE html>
<html lang="en">
<head>
<meta charset="UTF-8">
<meta name="viewport" content="width=device-width, initial-scale=1">
<title>Calendar <?php echo date('Y'); ?></title>

<link rel="stylesheet" href="calendar.css">

</head>
<body>

<div class="container">

    <?php 
        // Displays the view selector to switch between 'month', 'week', 'day', and 'year' views
        renderViewSwitcher($month, $year, $week, $view, $lang, $translations);

        // Add the loading element
        echo '<div id="loading" style="display: none;">Loading...</div>'; // Loading indicator

        // Wrapper for the calendar view
        echo '<div class="calendar-wrapper">';

            echo '<div id="container-calendar">';
                // Selects and displays the calendar view based on the user's choice
                if ($view === 'month') {

                    // Displays the monthly view with events for the month
                    renderMonthCalendar($month, $year, $events, $weekStart, $lang, $translations);

                } elseif ($view === 'week') {

                    // Displays the weekly view with events for the week
                    renderWeekView($month, $year, $week, $events, $weekStart, $lang, $translations, $workingStartTime, $workingEndTime);

                } elseif ($view === 'day') {

                    // Displays the daily view with events, including the hours of the day
                    renderDayViewWithHours($month, $year, $day, $events, $lang, $translations, $workingStartTime, $workingEndTime);
                    
                } elseif ($view === 'year') {

                    // Displays the yearly calendar with events for the year
                    renderYearCalendar($year, $events, $weekStart, $lang, $translations);
                }
            echo '</div>'; // Close the calendar container
        echo '</div>'; // Close the calendar wrapper
    ?>

</div>


<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.7.1/jquery.min.js"></script>
<script src="calendar.js?t=<?php echo time(); ?>" defer></script>

</body>
</html>